translate.convert.ini2po

Package translate :: Package convert :: Module ini2po |
[hide private]
[frames] | no frames]

# Module ini2po

source code

convert .ini files to Gettext PO localization files

Classes | [hide private]
| ini2po convert a .ini file to a .po file for handling the translation...

Functions | [hide private]
convertini(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt", dialect="default") Reads in `input_file` using ini, converts using ini2po, writes to `output_file` | source code
convertisl(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt", dialect="inno") | source code
main(argv=None) | source code

Imports: sys, po